@@ -6,7 +6,7 @@ use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use Carp qw(confess cluck);
 use DateTime;
@@ -217,7 +217,7 @@ sub get_station {
 			printf( " -> %s (%s / %s)\n", @{ $ret[-1] }{qw{name uic ds100}} );
 		}
 
-		if ( $opt{recursive} ) {
+		if ( $opt{recursive} and defined $station_node->getAttribute('meta') ) {
 			my @refs
 			  = uniq( split( m{ \| }x, $station_node->getAttribute('meta') ) );
 			@refs = grep { not( $_ ~~ \@seen or $_ ~~ \@queue ) } @refs;
@@ -536,7 +536,7 @@ Travel::Status::DE::IRIS - Interface to IRIS based web departure monitors.
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 DESCRIPTION
 
@@ -653,7 +653,7 @@ L<https://github.com/derf/Travel-Status-DE-IRIS>
 
 =head1 AUTHOR
 
-Copyright (C) 2013-2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2013-2016 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
